// Beginning user settings

// "only for test and calibration purposes; transmits a continuous 30MHz (AD9851 50MHz) signal" (Y / N)
#define TEST_MODE 'N'

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// call and power[mW]
const char CALL[7] = "DL1DUZ";  // 6 character callsign; 3rd character is forced to be a number; fill all blanks with " "
const uint16_t POWER = 1000;    // Power[mW] from 1 to 9999

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// "DDS crystal temperature sensor installed?" (Y / N)
#define TEMP_SENSOR_INSTALLED 'Y'

// "SWR meter installed?" (Y / N)
#define SWR_METER_INSTALLED 'Y'

// the type of DDS (AD9850 / AD9851)
#define AD9851

// the number of available bands (currently 11 [160-6m] or 10 [160-10m], depending on type of DDS)
const uint8_t BAND_COUNT = 11;

// base-frequencies for all bands (some may depend on your national frequqncy allocations)
const uint32_t BASE_FREQUENCY[BAND_COUNT] PROGMEM = {1838000,3570000,5366100,7040000,10140100,14097000,18106000,
                                                     21096000,24926000,28126000,50294400};

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// The status of the bands (enabled/disabled) is no longer defined at this point.

// This parameter can now be interactively modified during startup of the beacon by connecting the Arduino to a PC running
// a terminal program at 9600 baud. For the beacon to enter the setup dialog the "transmitter disabled" switch has to be
// set to "TX off" prior to power-up. The terminal software implemented at the Arduino programming environment
// (Tools -> Serial Monitor) will do the job. I also tested kitty_portable from "9bis software". In order to save you the
// setup I added a copy of that program including the ini-file to this package. Simply start the "exe", load the WSPR-beacon
// setup, set the right com-port (e.g. COM 1 2 3 ...) and open the connection. At the end of this file you'll find a
// screenshot showing how things should look like if all settings are ok.

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  
// beacon operating mode /// 0 = TX frequency will be randomly chosen within the band limits at each new
// transmission cycle; 1...194 = TX frequency will be fixed at "lower band limit" + 1...194 Hz
uint8_t beacon_mode = 0;

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// The beacon's duty cycle is no longer defined at this point but interactively modified during startup (see above).

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// the DDS clock frequency (at a nominal operating temperature of 35°C)
//const uint32_t DDS_CLK = 179997450;
const uint32_t DDS_CLK = 179997306; // 28.04.2023

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#if TEMP_SENSOR_INSTALLED == 'Y'
  // DDS temperature compensation (measured by a sensor mounted on top of DDS crystal
  const uint8_t TEMP_ARRAY_SIZE = 17;
  // ADC output = f(temperature @ crystal) /// stepwidh == 5K; 823 == 0°C; 499 == 35°C (baseline); 213 == 70°C
  const int16_t TEMP_X[TEMP_ARRAY_SIZE] PROGMEM = {1023,823,784,742,696,648,599,549,499,450,402,357,315,276,242,213,0};
  // DDS clock deviation [Hz] (0 == dev. @ nominal temp.)
  const int16_t TEMP_Y[TEMP_ARRAY_SIZE] PROGMEM = {1002,1002,913,831,739,617,447,222,0,-193,-361,-505,-629,-732,-819,-891,-891};
#endif

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// max. permissive SWR from 1.0 to 9.9 (e.g. 25 == 2.5)
const uint8_t SWR_LIMIT = 25;

#if SWR_METER_INSTALLED == 'Y'
  // SWR-meter polynomial (correcting nonlinearities of the SWR-gauge / must be adjusted depending on the
  // diodes used); SWR_x represents the DC output of the diode (hence value given by the ADC) and SWR_y the AC input to the
  // diode (all values in the 0...1023 scope of the ADC)
  const uint8_t SWR_ARRAY_SIZE = 10;

  const int16_t SWR_X[SWR_ARRAY_SIZE] PROGMEM = {0,10,20,31,41,51,61,72,82,1023};
  const int16_t SWR_Y[SWR_ARRAY_SIZE] PROGMEM = {0,18,37,52,69,81,92,102,111,1023};
#endif

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

uint16_t MAX_AGE = 1800; // maximum permissive age of GPS-datasets [seconds]
                         // currently set to 30 min.										
												
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// sets the temperature scale /// (0 = Celsius, 1 = Fahrenheit)
const uint8_t TEMP_SCALE = 0;

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// sets the speed unit /// (0 = km/h, 1 = mph, 2 = kn)
const uint8_t SPEED_UNIT = 0;

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// sets the distance unit /// (0 = m, 1 = ft)
const uint8_t DIST_UNIT = 0;

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// enable/disable some extra screens (0 = off, 1 = on)
const uint8_t COORDINATES = 1; // shows a screen displaying the current longitude and latitude
const uint8_t ALT_SPEED = 1; // shows a screen displaying the current altitude and speed over ground

// Sorry, but having access to exact time and coordinates I couldn't resist giving the beacon some basic skills in
// astromechanics. So if you're interested in the heavens above, you may want to activate those features below.
const uint8_t SUN = 1; // shows a screen displaying time of sunrise & sunset
const uint8_t MOON = 1; // shows a screen displaying time of moonrise & moonset plus the Moon's phase (e.g. 53% decreasing)

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// port assignment

#if TEMP_SENSOR_INSTALLED == 'Y'
  // DDS crystal temperature sencor (analog pin)
  const uint8_t DDS_TEMP_PIN = A0;
#endif

#if SWR_METER_INSTALLED == 'Y'
  // SWR-meter (analog pins)
  const uint8_t SWR_REF_PIN = A4;
  const uint8_t SWR_FWD_PIN = A5;
#endif

// Transmitter enabled (digital pin)
const uint8_t TRANSMITTER_ENABLED_PIN = 3;

// HD44780 (digital pins)
const uint8_t RS_PIN = 13;
const uint8_t ENABLE_PIN = 12;
const uint8_t D4_PIN = 11;
const uint8_t D5_PIN = 10;
const uint8_t D6_PIN = 9;
const uint8_t D7_PIN = 8;
const uint8_t LED = 1;

// AD9851(51) / digital pins
const uint8_t  W_CLK_PIN = 7;
const uint8_t  FQ_UD_PIN = 6;
const uint8_t  DATA_PIN = 5;
const uint8_t  RESET_PIN = 4;

// GPS-module receiver (digital pin capable of triggering interrupts)
const uint8_t GPS_INPUT_PIN = 2;

// End user settings

/*
WSPR beacon setup dialog.

Current band settings:

160m is off
80m is off
60m is off
40m is off
30m is off
20m is off
17m is off
15m is on
12m is off
10m is off
6m is off

Would you like to change these settings (y/n)? NO

The beacon's duty cycle is 1/2 = 50.0%.
To increase/decrease (repeatedly) press 'i' or 'd', to quit press 'q'.

The beacon is currently on during daytime, switching about 1h after sunrise/-set.
To change press either 'd' for daytime, 'n' for nighttime or 'c' for constant, to quit press 'q'.

Would you like to discard changes and repeat setup? (y/n)? NO

Done! Settings have been saved. You may now disconnect and restart the beacon.
*/
